==> gitlab-foss-v18.6.2.tar.bz2: gitlab-foss-v18.6.2/app/assets/javascripts/ci/pipeline_details/pipelines_index.js <==
import { GlToast } from '@gitlab/ui';
import Vue from 'vue';
import VueApollo from 'vue-apollo';
import createDefaultClient from '~/lib/graphql';
import {
  buildUrlWithCurrentLocation,
  historyReplaceState,
  parseBoolean,
} from '~/lib/utils/common_utils';
import { doesHashExistInUrl } from '~/lib/utils/url_utility';
import { __ } from '~/locale';
import Translate from '~/vue_shared/translate';
import Pipelines from '~/ci/pipelines_page/pipelines.vue';
import PipelinesGraphql from '~/ci/pipelines_page/pipelines_graphql.vue';
import PipelinesStore from './stores/pipelines_store';

Vue.use(Translate);
Vue.use(GlToast);
Vue.use(VueApollo);

const apolloProvider = new VueApollo({
  defaultClient: createDefaultClient(),
});

export const initPipelinesIndex = (selector = '#pipelines-list-vue') => {
  const el = document.querySelector(selector);
  if (!el) {
    return null;
  }

  const {
    endpoint,
    artifactsEndpoint,
    artifactsEndpointPlaceholder,
    pipelineSchedulesPath,
    newPipelinePath,
    pipelineEditorPath,
    suggestedCiTemplates,
    canCreatePipeline,
    hasGitlabCi,
    resetCachePath,
    projectId,
    defaultBranchName,
    params,
    fullPath,
    visibilityPipelineIdType,
    showJenkinsCiPrompt,
    identityVerificationPath,
    identityVerificationRequired,
    pipelinesAnalyticsPath,
    usesExternalConfig,
    emptyStateIllustrationPath,
  } = el.dataset;

  return new Vue({
    el,
    apolloProvider,
    provide: {
      artifactsEndpoint,
      artifactsEndpointPlaceholder,
      canCreatePipeline: parseBoolean(canCreatePipeline),
      defaultBranchName,
      fullPath,
      manualActionsLimit: 50,
      pipelineEditorPath,
      pipelineSchedulesPath,
      pipelinesAnalyticsPath,
      projectId,
      identityVerificationPath,
      identityVerificationRequired: parseBoolean(identityVerificationRequired),
      suggestedCiTemplates: JSON.parse(suggestedCiTemplates),
      showJenkinsCiPrompt: parseBoolean(showJenkinsCiPrompt),
      usesExternalConfig: parseBoolean(usesExternalConfig),
      emptyStateIllustrationPath,
    },
    data() {
      return {
        store: new PipelinesStore(),
      };
    },
    created() {
      if (doesHashExistInUrl('delete_success')) {
        this.$toast.show(__('The pipeline has been deleted'));
        historyReplaceState(buildUrlWithCurrentLocation());
      }
    },
    render(createElement) {
      return createElement(Pipelines, {
        props: {
          defaultVisibilityPipelineIdType: visibilityPipelineIdType,
          endpoint,
          hasGitlabCi: parseBoolean(hasGitlabCi),
          newPipelinePath,
          params: JSON.parse(params),
          resetCachePath,
          store: this.store,
        },
      });
    },
  });
};

export const initPipelinesIndexGraphql = (selector = '#pipelines-list-vue') => {
  const el = document.querySelector(selector);

  if (!el) {
    return null;
  }

  const {
    artifactsEndpoint,
    artifactsEndpointPlaceholder,
    fullPath,
    newPipelinePath,
    resetCachePath,
    pipelinesAnalyticsPath,
    identityVerificationRequired,
    identityVerificationPath,
    visibilityPipelineIdType,
    params,
    projectId,
    defaultBranchName,
    pipelineSchedulesPath,
    suggestedCiTemplates,
    canCreatePipeline,
    showJenkinsCiPrompt,
    usesExternalConfig,
    emptyStateIllustrationPath,
    pipelineEditorPath,
  } = el.dataset;

  return new Vue({
    el,
    apolloProvider,
    provide: {
      artifactsEndpoint,
      artifactsEndpointPlaceholder,
      fullPath,
      newPipelinePath,
      resetCachePath,
      pipelinesAnalyticsPath,
      identityVerificationRequired: parseBoolean(identityVerificationRequired),
      identityVerificationPath,
      projectId,
      defaultBranchName,
      manualActionsLimit: 50,
      pipelineSchedulesPath,
      suggestedCiTemplates: JSON.parse(suggestedCiTemplates),
      canCreatePipeline: parseBoolean(canCreatePipeline),
      showJenkinsCiPrompt: parseBoolean(showJenkinsCiPrompt),
      usesExternalConfig: parseBoolean(usesExternalConfig),
      emptyStateIllustrationPath,
      pipelineEditorPath,
    },
    created() {
      if (doesHashExistInUrl('delete_success')) {
        this.$toast.show(__('The pipeline has been deleted'));
        historyReplaceState(buildUrlWithCurrentLocation());
      }
    },
    render(createElement) {
      return createElement(PipelinesGraphql, {
        props: {
          defaultVisibilityPipelineIdType: visibilityPipelineIdType,
          params: JSON.parse(params),
        },
      });
    },
  });
};

==> gitlab-foss-v18.7.1.tar.bz2: gitlab-foss-v18.7.1/app/assets/javascripts/ci/pipeline_details/pipelines_index.js <==
import { GlToast } from '@gitlab/ui';
import Vue from 'vue';
import VueApollo from 'vue-apollo';
import createDefaultClient from '~/lib/graphql';
import {
  buildUrlWithCurrentLocation,
  historyReplaceState,
  parseBoolean,
} from '~/lib/utils/common_utils';
import { doesHashExistInUrl } from '~/lib/utils/url_utility';
import { __ } from '~/locale';
import Translate from '~/vue_shared/translate';
import Pipelines from '~/ci/pipelines_page/pipelines.vue';
import PipelinesGraphql from '~/ci/pipelines_page/pipelines_graphql.vue';
import { DEFAULT_MANUAL_ACTIONS_LIMIT } from '../constants';
import PipelinesStore from './stores/pipelines_store';

Vue.use(Translate);
Vue.use(GlToast);
Vue.use(VueApollo);

const apolloProvider = new VueApollo({
  defaultClient: createDefaultClient(),
});

export const initPipelinesIndex = (selector = '#pipelines-list-vue') => {
  const el = document.querySelector(selector);
  if (!el) {
    return null;
  }

  const {
    endpoint,
    artifactsEndpoint,
    artifactsEndpointPlaceholder,
    pipelineSchedulesPath,
    newPipelinePath,
    pipelineEditorPath,
    suggestedCiTemplates,
    canCreatePipeline,
    hasGitlabCi,
    resetCachePath,
    projectId,
    defaultBranchName,
    params,
    fullPath,
    visibilityPipelineIdType,
    showJenkinsCiPrompt,
    identityVerificationPath,
    identityVerificationRequired,
    pipelinesAnalyticsPath,
    usesExternalConfig,
    emptyStateIllustrationPath,
  } = el.dataset;

  return new Vue({
    el,
    apolloProvider,
    provide: {
      artifactsEndpoint,
      artifactsEndpointPlaceholder,
      canCreatePipeline: parseBoolean(canCreatePipeline),
      defaultBranchName,
      fullPath,
      manualActionsLimit: DEFAULT_MANUAL_ACTIONS_LIMIT,
      pipelineEditorPath,
      pipelineSchedulesPath,
      pipelinesAnalyticsPath,
      projectId,
      identityVerificationPath,
      identityVerificationRequired: parseBoolean(identityVerificationRequired),
      suggestedCiTemplates: JSON.parse(suggestedCiTemplates),
      showJenkinsCiPrompt: parseBoolean(showJenkinsCiPrompt),
      usesExternalConfig: parseBoolean(usesExternalConfig),
      emptyStateIllustrationPath,
    },
    data() {
      return {
        store: new PipelinesStore(),
      };
    },
    created() {
      if (doesHashExistInUrl('delete_success')) {
        this.$toast.show(__('The pipeline has been deleted'));
        historyReplaceState(buildUrlWithCurrentLocation());
      }
    },
    render(createElement) {
      return createElement(Pipelines, {
        props: {
          defaultVisibilityPipelineIdType: visibilityPipelineIdType,
          endpoint,
          hasGitlabCi: parseBoolean(hasGitlabCi),
          newPipelinePath,
          params: JSON.parse(params),
          resetCachePath,
          store: this.store,
        },
      });
    },
  });
};

export const initPipelinesIndexGraphql = (selector = '#pipelines-list-vue') => {
  const el = document.querySelector(selector);

  if (!el) {
    return null;
  }

  const {
    artifactsEndpoint,
    artifactsEndpointPlaceholder,
    fullPath,
    newPipelinePath,
    resetCachePath,
    pipelinesAnalyticsPath,
    identityVerificationRequired,
    identityVerificationPath,
    visibilityPipelineIdType,
    params,
    projectId,
    defaultBranchName,
    pipelineSchedulesPath,
    suggestedCiTemplates,
    canCreatePipeline,
    showJenkinsCiPrompt,
    usesExternalConfig,
    emptyStateIllustrationPath,
    pipelineEditorPath,
  } = el.dataset;

  return new Vue({
    el,
    apolloProvider,
    provide: {
      artifactsEndpoint,
      artifactsEndpointPlaceholder,
      fullPath,
      newPipelinePath,
      resetCachePath,
      pipelinesAnalyticsPath,
      identityVerificationRequired: parseBoolean(identityVerificationRequired),
      identityVerificationPath,
      projectId,
      defaultBranchName,
      manualActionsLimit: DEFAULT_MANUAL_ACTIONS_LIMIT,
      pipelineSchedulesPath,
      suggestedCiTemplates: JSON.parse(suggestedCiTemplates),
      canCreatePipeline: parseBoolean(canCreatePipeline),
      showJenkinsCiPrompt: parseBoolean(showJenkinsCiPrompt),
      usesExternalConfig: parseBoolean(usesExternalConfig),
      emptyStateIllustrationPath,
      pipelineEditorPath,
    },
    created() {
      if (doesHashExistInUrl('delete_success')) {
        this.$toast.show(__('The pipeline has been deleted'));
        historyReplaceState(buildUrlWithCurrentLocation());
      }
    },
    render(createElement) {
      return createElement(PipelinesGraphql, {
        props: {
          defaultVisibilityPipelineIdType: visibilityPipelineIdType,
          params: JSON.parse(params),
        },
      });
    },
  });
};
